==> qore-1.13.0.tar.bz2: qore-1.13.0/docs/modules/ConnectionProvider/html/class_connection_provider_1_1_http_connection.js <==
var class_connection_provider_1_1_http_connection =
[
    [ "constructor", "class_connection_provider_1_1_http_connection.html#a49963a8f907c65208e5d767b95873d50", null ],
    [ "getConnectionSchemeInfoImpl", "class_connection_provider_1_1_http_connection.html#a57adcd9fc48cca761366eb60df9961f1", null ],
    [ "getDataProvider", "class_connection_provider_1_1_http_connection.html#a0219ebc46a8d13043ad6fd0bf45c8938", null ],
    [ "getImpl", "class_connection_provider_1_1_http_connection.html#a55a092f9c4ab0e794c52bf677dfba749", null ],
    [ "getType", "class_connection_provider_1_1_http_connection.html#a615ceb86bc26968ddd0208c6e68bacc7", null ],
    [ "hasDataProvider", "class_connection_provider_1_1_http_connection.html#a0d780886a3d2444629f671427b5ae690", null ],
    [ "setChildCapabilities", "class_connection_provider_1_1_http_connection.html#adb09bf48654463c1021481f5b4fdc02b", null ],
    [ "startPollConnect", "class_connection_provider_1_1_http_connection.html#ae8420e4f93c5d23cc96af896e52444b8", null ],
    [ "supportsPollingApi", "class_connection_provider_1_1_http_connection.html#ad3fa91595e9938d4e094ad0c729d7b69", null ],
    [ "ConnectionScheme", "class_connection_provider_1_1_http_connection.html#a0e389e7aaa0e18931fafee1db1f20c71", null ],
    [ "DefaultOptions", "class_connection_provider_1_1_http_connection.html#ae07d2997d932b77d60c84ef63afa1d13", null ],
    [ "Options", "class_connection_provider_1_1_http_connection.html#a7d2c0780ee703aa1e08e472b0dfa5c80", null ]
];

==> qore-2.0.0.tar.bz2: qore-2.0.0/docs/modules/ConnectionProvider/html/class_connection_provider_1_1_http_connection.js <==
var class_connection_provider_1_1_http_connection =
[
    [ "constructor", "class_connection_provider_1_1_http_connection.html#ab437b586827da78efdfa9e97e260aa75", null ],
    [ "constructor", "class_connection_provider_1_1_http_connection.html#ae9f8c59695c805168b10bd262fadab54", null ],
    [ "getConnectionOptions", "class_connection_provider_1_1_http_connection.html#af63b212bf30779db30b8b0357a4c51ef", null ],
    [ "getConnectionSchemeInfoImpl", "class_connection_provider_1_1_http_connection.html#a57adcd9fc48cca761366eb60df9961f1", null ],
    [ "getDataProvider", "class_connection_provider_1_1_http_connection.html#ad685feedee5020e30b9373683b40a6ae", null ],
    [ "getImpl", "class_connection_provider_1_1_http_connection.html#a55a092f9c4ab0e794c52bf677dfba749", null ],
    [ "getType", "class_connection_provider_1_1_http_connection.html#a615ceb86bc26968ddd0208c6e68bacc7", null ],
    [ "hasDataProvider", "class_connection_provider_1_1_http_connection.html#a0d780886a3d2444629f671427b5ae690", null ],
    [ "setChildCapabilities", "class_connection_provider_1_1_http_connection.html#adb09bf48654463c1021481f5b4fdc02b", null ],
    [ "startPollConnect", "class_connection_provider_1_1_http_connection.html#aace6f0a3316d9be3d47fdb8dd7de9dfa", null ],
    [ "supportsPollingApi", "class_connection_provider_1_1_http_connection.html#ad3fa91595e9938d4e094ad0c729d7b69", null ],
    [ "ConnectionScheme", "class_connection_provider_1_1_http_connection.html#a0e389e7aaa0e18931fafee1db1f20c71", null ],
    [ "Options", "class_connection_provider_1_1_http_connection.html#a7d2c0780ee703aa1e08e472b0dfa5c80", null ]
];
